changeset 82434:e460d01bb038

(report-emacs-bug): Make MS-DOS a special case (there's no build number).
author Michaël Cadilhac <michael.cadilhac@lrde.org>
date Fri, 17 Aug 2007 19:38:38 +0000
parents 4e36d5b6841f
children 138c9c03943c
files lisp/mail/emacsbug.el
diffstat 1 files changed, 10 insertions(+), 5 deletions(-) [+]
line wrap: on
line diff
--- a/lisp/mail/emacsbug.el	Fri Aug 17 19:27:49 2007 +0000
+++ b/lisp/mail/emacsbug.el	Fri Aug 17 19:38:38 2007 +0000
@@ -75,11 +75,16 @@
   (interactive (reverse (list (recent-keys) (read-string "Bug Subject: "))))
   ;; The syntax `version;' is preferred to `[version]' because the
   ;; latter could be mistakenly stripped by mailing software.
-  (when (string-match "^\\(\\([.0-9]+\\)*\\)\\.[0-9]+$" emacs-version)
-    (setq topic (concat (match-string 1 emacs-version) "; " topic)))
-  ;; If there are four numbers in emacs-version, this is a pretest
-  ;; version.
-  (let* ((pretest-p (string-match "\\..*\\..*\\." emacs-version))
+  (if (eq system-type 'ms-dos)
+      (setq topic (concat emacs-version "; " topic))
+    (when (string-match "^\\(\\([.0-9]+\\)*\\)\\.[0-9]+$" emacs-version)
+      (setq topic (concat (match-string 1 emacs-version) "; " topic))))
+  ;; If there are four numbers in emacs-version (three for MS-DOS),
+  ;; this is a pretest version.
+  (let* ((pretest-p (string-match (if (eq system-type 'ms-dos)
+				      "\\..*\\."
+				    "\\..*\\..*\\.")
+				  emacs-version))
 	 (from-buffer (current-buffer))
 	 (reporting-address (if pretest-p
 				report-emacs-bug-pretest-address